@@ -1,4 +1,7 @@
-jQuery(document).ready(function ($) {
+(function($) {
+// CMS.$ will be passed for $
+$(document).ready(function () {
+
 	CKEDITOR.plugins.add('cmsplugins', {
 
 		// Register the icons. They must match command names.
@@ -8,28 +11,27 @@ jQuery(document).ready(function ($) {
 		init: function(editor) {
 			var that = this;
 
-			this.lang = CMS.CKEditor.options.cmsLang;
-			this.plugins = CMS.CKEditor.options.cmsPlugins;
-			this.page_id = CMS.CKEditor.options.cmsPage;
+			this.options = CMS.CKEditor.options.settings;
 			this.editor = editor;
+			this.data = null;
 
 			// don't do anything if there are no plugins defined
-			if (this.plugins.length === 0) return;
+			if(this.options.plugins.length === 0) return;
 
 			this.setupDialog();
 
 			// add the button
 			this.editor.ui.add('cmsplugins', CKEDITOR.UI_PANELBUTTON, {
 				'toolbar': 'cms,0',
-				'label': this.lang.toolbar,
-				'title': this.lang.toolbar,
+				'label': this.options.lang.toolbar,
+				'title': this.options.lang.toolbar,
 				'className' : 'cke_panelbutton__cmsplugins',
 				'modes': { wysiwyg:1 },
 				'editorFocus': 1,
 
 				'panel': {
 					'css': [CKEDITOR.skin.getPath('editor')].concat(that.editor.config.contentsCss),
-					'attributes': { role: 'cmsplugins', 'aria-label': this.lang.aria }
+					'attributes': { role: 'cmsplugins', 'aria-label': this.options.lang.aria }
 				},
 
 				// this is called when creating the dropdown list
@@ -72,7 +74,7 @@ jQuery(document).ready(function ($) {
 			var definition = function () { return {
 				'title': '',
 				'minWidth': 600,
-				'minHeight': 150,
+				'minHeight': 200,
 				'contents': [{
 					'elements': [{ type: 'html', html: '<iframe style="position:absolute; left:0; top:0; width:100%; height:100%; border:none;" />' }]
 				}],
@@ -82,13 +84,11 @@ jQuery(document).ready(function ($) {
 
 					// catch the reload event and reattach
 					var reload = CMS.API.Helpers.reloadBrowser;
-					CMS.API.Helpers.reloadBrowser = function(id, icon, alt) {
+
+					CMS.API.Helpers.reloadBrowser = function() {
 						CKEDITOR.dialog.getCurrent().hide();
-						that.insertPlugin({
-							'id': id,
-							'icon': icon,
-							'alt': alt
-						});
+
+						that.insertPlugin(that.data);
 
 						CMS.API.Helpers.reloadBrowser = reload;
 						return false;
@@ -105,12 +105,11 @@ jQuery(document).ready(function ($) {
 			var tpl = '<div class="cke_panel_block">';
 
 			// loop through the groups
-			$.each(this.plugins, function (i, group) {
+			$.each(this.options.plugins, function (i, group) {
 				// add template
 				tpl += '<h1 class="cke_panel_grouptitle">' + group.group + '</h1>';
 				tpl += '<ul role="presentation" class="cke_panel_list">';
 				// loop through the plugins
-				// TODO the url is static, will change for 3.0
 				$.each(group.items, function (ii, item) {
 					tpl += '<li class="cke_panel_listItem"><a href="#" rel="' + item.type + '">' + item.title + '</a></li>';
 				});
@@ -125,7 +124,7 @@ jQuery(document).ready(function ($) {
 		setupContextMenu: function () {
 			this.editor.addMenuGroup('cmspluginsGroup');
 			this.editor.addMenuItem('cmspluginsItem', {
-				label: this.lang.edit,
+				label: this.options.lang.edit,
 				icon: '../ckeditor_plugins/cmsplugins/icons/cmsplugins.png',
 				command: 'cmspluginsEdit',
 				group: 'cmspluginsGroup'
@@ -147,13 +146,12 @@ jQuery(document).ready(function ($) {
 
 			// now tweak in dynamic stuff
 			var dialog = CKEDITOR.dialog.getCurrent();
-			$(dialog.parts.title.$).text(this.lang.edit);
+			$(dialog.parts.title.$).text(this.options.lang.edit);
 			$(dialog.parts.contents.$).find('iframe').attr('src', '../' + id + '/?_popup=1&no_preview')
 				.bind('load', function () {
-					$(this).contents().find('.plugin-submit-row').hide().end()
-						.find('#container').css('min-width', 0);
+					$(this).contents().find('.submit-row').hide().end()
+						.find('#container').css('min-width', 0).css('padding', 0);
 				});
-				dialog.data = { 'id': el.getAttribute('id') };
 		},
 
 		addPlugin: function (item, panel) {
@@ -166,39 +164,52 @@ jQuery(document).ready(function ($) {
 			this.editor.focus();
 			this.editor.fire('saveSnapshot');
 
+			// gather data
+			var data = {
+				'placeholder_id': this.options.placeholder_id,
+				'plugin_type': item.attr('rel'),
+				'parent_id': this.options.plugin_id,
+				'plugin_language': 'en'
+			};
+
 			// lets do some ajax
 			$.ajax({
 				'type': 'POST',
-				'url': 'add-plugin/',
-				'data': {
-					parent_id: that.page_id,
-					plugin_type: item.attr('rel')
-				},
-				'success': function (plugin_id) {
-					if(plugin_id === 'error') return false;
+				'url': this.options.add_plugin_url,
+				'data': data,
+				'success': function (data) {
+					// cancel if error is returned
+					if(data === 'error') return false;
 
-					that.addPluginDialog(item, plugin_id);
+					// attach static icon to the object
+					data.alt = item.attr('rel');
+					data.id = parseInt(data.url.split('/')[data.url.split('/').length - 2]);
+					data.icon = that.options.static_url + 'ckeditor_plugins/cmsplugins/icons/' + item.attr('rel') + '.png';
+
+					// set new data, will be used for reload browser birdge
+					that.data = data;
+
+					// trigger dialog
+					that.addPluginDialog(item, data);
 				},
-				'error': function () {
+				'error': function (error) {
 					alert('There was an error creating the plugin.');
 				}
 			});
 		},
 
-		addPluginDialog: function (item, id) {
+		addPluginDialog: function (item, data) {
 			// open the dialog
 			this.editor.openDialog('cmspluginsDialog');
 
 			// now tweak in dynamic stuff
 			var dialog = CKEDITOR.dialog.getCurrent();
-				$(dialog.parts.title.$).text(this.lang.add);
-				$(dialog.parts.contents.$).find('iframe').attr('src', '../' + id + '/?_popup=1')
+				$(dialog.parts.title.$).text(this.options.lang.add);
+				$(dialog.parts.contents.$).find('iframe').attr('src', data.url)
 					.bind('load', function () {
-						$(this).contents().find('.plugin-submit-row').hide().end()
-							.find('#container').css('min-width', 0);
+						$(this).contents().find('.submit-row').hide().end()
+							.find('#container').css('min-width', 0).css('padding', 0);
 					});
-				// set new data
-				dialog.data = { 'id': id };
 		},
 
 		insertPlugin: function (data) {
@@ -214,4 +225,6 @@ jQuery(document).ready(function ($) {
 		}
 
 	});
-});
\ No newline at end of file
+
+});
+})(CMS.$);
