@@ -10,7 +10,7 @@ from cms.utils import cms_static_url
 from django.utils import simplejson
 
 class TextEditorWidget(Textarea):
-    def __init__(self, attrs=None, installed_plugins=None, pk=None):
+    def __init__(self, attrs=None, installed_plugins=None, pk=None, placeholder=None):
         """
         Create a widget for editing text + plugins.
 
@@ -19,6 +19,7 @@ class TextEditorWidget(Textarea):
         super(TextEditorWidget, self).__init__(attrs)
         self.installed_plugins = installed_plugins
         self.pk = pk
+        self.placeholder = placeholder
 
     def render_textarea(self, name, value, attrs=None):
         return super(TextEditorWidget, self).render(name, value, attrs)
@@ -32,16 +33,10 @@ class TextEditorWidget(Textarea):
             'STATIC_URL': settings.STATIC_URL,
             'installed_plugins': self.installed_plugins,
             'plugin_pk': self.pk,
+            'placeholder': self.placeholder
         }
         return mark_safe(render_to_string('cms/plugins/widgets/ckeditor.html', context))
 
     def render(self, name, value, attrs=None):
         return self.render_textarea(name, value, attrs) + \
             self.render_additions(name, value, attrs)
-
-    class Media:
-        css = {
-            'all': ('%scss/cms.ckeditor.css' % settings.STATIC_URL,)
-        }
-        js = ('%sckeditor/ckeditor.js' % settings.STATIC_URL,
-              '%sjs/cms.ckeditor.js' % settings.STATIC_URL,)
